==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebPathSegmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPathSegmentDescription } from "./WebPathSegmentDescription";
/**
 * @hidden
 */
export let WebPathSegmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPathSegmentDescriptionMetadata extends Base {
        static b(a) {
            if (WebPathSegmentDescriptionMetadata.a == null) {
                WebPathSegmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPathSegmentDescriptionMetadata.c(WebPathSegmentDescriptionMetadata.a);
            }
            if (a.j(WebPathSegmentDescriptionMetadata.a)) {
                return;
            }
            a.y(WebPathSegmentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PathSegment");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("RowID", "Unknown");
            a.item("RowIslandKey", "String");
        }
        static d(a) {
            WebPathSegmentDescriptionMetadata.b(a);
            a.aa("WebPathSegment", () => new WebPathSegmentDescription());
            a.z("WebPathSegment", WebPathSegmentDescriptionMetadata.a);
        }
    }
    WebPathSegmentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPathSegmentDescriptionMetadata, 'WebPathSegmentDescriptionMetadata');
    WebPathSegmentDescriptionMetadata.a = null;
    return WebPathSegmentDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebPathSegmentDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPathSegmentDescription } from "./WebPathSegmentDescription";
/**
 * @hidden
 */
export let WebPathSegmentDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebPathSegmentDescriptionMetadata extends Base {
        static b(a) {
            if (WebPathSegmentDescriptionMetadata.a == null) {
                WebPathSegmentDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebPathSegmentDescriptionMetadata.c(WebPathSegmentDescriptionMetadata.a);
            }
            if (a.k(WebPathSegmentDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebPathSegmentDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:PathSegment");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("RowID", "Unknown");
            a.item("RowIslandKey", "String");
        }
        static d(a) {
            WebPathSegmentDescriptionMetadata.b(a);
            a.ac("WebPathSegment", () => new WebPathSegmentDescription());
            a.ab("WebPathSegment", WebPathSegmentDescriptionMetadata.a);
        }
    }
    WebPathSegmentDescriptionMetadata.$t = /*@__PURE__*/ markType(WebPathSegmentDescriptionMetadata, 'WebPathSegmentDescriptionMetadata');
    WebPathSegmentDescriptionMetadata.a = null;
    return WebPathSegmentDescriptionMetadata;
})();
